@@ -1,7 +1,7 @@
-pub mod first_last;
 pub mod flags;
 pub mod map;
 pub mod opt_map;
+pub mod order;
 pub mod sizes;
 pub mod types;
 pub mod vec;
